# pymugi

[![PyPI](https://img.shields.io/pypi/v/pymugi.svg)](https://pypi.python.org/pypi/pymugi)
[![Build Status](https://travis-ci.com/Wh1terat/pymugi.svg?branch=master)](https://travis-ci.com/github/Wh1terat/pymugi)

**pymugi** provides a pure python3 implementation of Hitachi's MUGI PRNG

Based upon: http://www.hitachi.com/rd/yrl/crypto/mugi/mugi_spe.pdf
